# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`pcp`](#pcp): Manage PCP

#### Private Classes

* `pcp::config`
* `pcp::install`
* `pcp::resources`
* `pcp::service`
* `pcp::user`

### Defined types

* [`pcp::pmda`](#pcp--pmda): Install, enable and optionally configure a PMDA
* [`pcp::pmie`](#pcp--pmie): Configure a pmie
* [`pcp::pmlogger`](#pcp--pmlogger): Configure a pmlogger

## Classes

### <a name="pcp"></a>`pcp`

Manage PCP

#### Examples

##### 

```puppet
include ::pcp
```

#### Parameters

The following parameters are available in the `pcp` class:

* [`ensure`](#-pcp--ensure)
* [`package_ensure`](#-pcp--package_ensure)
* [`packages`](#-pcp--packages)
* [`extra_packages`](#-pcp--extra_packages)
* [`service_ensure`](#-pcp--service_ensure)
* [`service_enable`](#-pcp--service_enable)
* [`enable_pmproxy`](#-pcp--enable_pmproxy)
* [`manage_user`](#-pcp--manage_user)
* [`pcp_group_gid`](#-pcp--pcp_group_gid)
* [`pcp_user_uid`](#-pcp--pcp_user_uid)
* [`cron_ensure`](#-pcp--cron_ensure)
* [`pmlogger_cron_template`](#-pcp--pmlogger_cron_template)
* [`pmie_cron_template`](#-pcp--pmie_cron_template)
* [`include_default_pmlogger`](#-pcp--include_default_pmlogger)
* [`include_default_pmie`](#-pcp--include_default_pmie)
* [`pmlogger_daily_args`](#-pcp--pmlogger_daily_args)
* [`pcp_conf_configs`](#-pcp--pcp_conf_configs)
* [`pmdas`](#-pcp--pmdas)
* [`pmies`](#-pcp--pmies)
* [`pmloggers`](#-pcp--pmloggers)

##### <a name="-pcp--ensure"></a>`ensure`

Data type: `Enum['running', 'stopped', 'absent']`

Defines state of PCP.

Default value: `'running'`

##### <a name="-pcp--package_ensure"></a>`package_ensure`

Data type: `String`

Package ensure property.

Default value: `'present'`

##### <a name="-pcp--packages"></a>`packages`

Data type: `Array`

Array of packages to install for PCP

Default value: `['pcp', 'pcp-conf', 'pcp-doc', 'pcp-libs', 'perl-PCP-PMDA', 'python-pcp', 'pcp-selinux']`

##### <a name="-pcp--extra_packages"></a>`extra_packages`

Data type: `Array`

Extra packages to install

Default value: `[]`

##### <a name="-pcp--service_ensure"></a>`service_ensure`

Data type: `Optional[String]`

Set service ensure property for `pmcd`, `pmie` and `pmlogger` services.
Default is based on `ensure` parameter.

Default value: `undef`

##### <a name="-pcp--service_enable"></a>`service_enable`

Data type: `Optional[Boolean]`

Set service enable property for `pmcd`, `pmie` and `pmlogger` services.
Default is based on `ensure` parameter.

Default value: `undef`

##### <a name="-pcp--enable_pmproxy"></a>`enable_pmproxy`

Data type: `Boolean`

Boolean that determines if pmproxy service is running/enabled.

Default value: `false`

##### <a name="-pcp--manage_user"></a>`manage_user`

Data type: `Boolean`

Boolean that sets if pcp user / group is managed.

Default value: `true`

##### <a name="-pcp--pcp_group_gid"></a>`pcp_group_gid`

Data type: `Optional[Integer]`

pcp group GID.

Default value: `undef`

##### <a name="-pcp--pcp_user_uid"></a>`pcp_user_uid`

Data type: `Optional[Integer]`

pcp user UID.

Default value: `undef`

##### <a name="-pcp--cron_ensure"></a>`cron_ensure`

Data type: `Optional[String]`

Ensure passed to cron files.
Default based on value of `ensure`.

Default value: `undef`

##### <a name="-pcp--pmlogger_cron_template"></a>`pmlogger_cron_template`

Data type: `String`

Template used for pmlogger cron.

Default value: `'pcp/pcp-pmlogger.cron.erb'`

##### <a name="-pcp--pmie_cron_template"></a>`pmie_cron_template`

Data type: `String`

Template used for pmie cron.

Default value: `'pcp/pcp-pmie.cron.erb'`

##### <a name="-pcp--include_default_pmlogger"></a>`include_default_pmlogger`

Data type: `Boolean`

Boolean that determines if default install pmlogger is installed.

Default value: `true`

##### <a name="-pcp--include_default_pmie"></a>`include_default_pmie`

Data type: `Boolean`

Boolean that determines if default install pmie is installed.

Default value: `true`

##### <a name="-pcp--pmlogger_daily_args"></a>`pmlogger_daily_args`

Data type: `String`

Arguments given to pmlogger_daily that is executed via cron.

Default value: `'-X xz -x 3'`

##### <a name="-pcp--pcp_conf_configs"></a>`pcp_conf_configs`

Data type: `Hash`

Hash of configs to manage in /etc/pcp.conf.

Default value: `{}`

##### <a name="-pcp--pmdas"></a>`pmdas`

Data type: `Hash`

Hash that defines `pcp::pmda` resources.

Default value: `{}`

##### <a name="-pcp--pmies"></a>`pmies`

Data type: `Hash`

Hash that defines `pcp::pmie` resources.

Default value: `{}`

##### <a name="-pcp--pmloggers"></a>`pmloggers`

Data type: `Hash`

Hash that defines `pcp::pmlogger` resources.

Default value: `{}`

## Defined types

### <a name="pcp--pmda"></a>`pcp::pmda`

Install, enable and optionally configure a PMDA

#### Examples

##### 

```puppet
pcp::pmda { 'nfsclient':
  ensure => 'present',
}
```

#### Parameters

The following parameters are available in the `pcp::pmda` defined type:

* [`ensure`](#-pcp--pmda--ensure)
* [`has_package`](#-pcp--pmda--has_package)
* [`package_name`](#-pcp--pmda--package_name)
* [`remove_package`](#-pcp--pmda--remove_package)
* [`config_path`](#-pcp--pmda--config_path)
* [`config_content`](#-pcp--pmda--config_content)
* [`config_source`](#-pcp--pmda--config_source)
* [`args`](#-pcp--pmda--args)

##### <a name="-pcp--pmda--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Ensure property for the PMDA.
Valid values are `'present'` and `'absent'`.
Default is `'present'`.

Default value: `'present'`

##### <a name="-pcp--pmda--has_package"></a>`has_package`

Data type: `Boolean`

Boolean that determines of a package is associated with the PMDA.
Default is `true`.

Default value: `true`

##### <a name="-pcp--pmda--package_name"></a>`package_name`

Data type: `Optional[String]`

Package name of PMDA.
Default is `pcp-pmda-$name`.

Default value: `undef`

##### <a name="-pcp--pmda--remove_package"></a>`remove_package`

Data type: `Boolean`

Boolean that determines if the package should be removed when `ensure` is `absent`.
Default is `false`.

Default value: `false`

##### <a name="-pcp--pmda--config_path"></a>`config_path`

Data type: `Optional[Stdlib::Absolutepath]`

Configuration file path for this PMDA.
Default is `/var/lib/pcp/config/${name}/${name}.conf`.

Default value: `undef`

##### <a name="-pcp--pmda--config_content"></a>`config_content`

Data type: `Optional[String]`

Configuration file content for the PMDA.
Default is `undef`.

Default value: `undef`

##### <a name="-pcp--pmda--config_source"></a>`config_source`

Data type: `Optional[String]`

Configuration file source for the PMDA.
Default is `undef`.

Default value: `undef`

##### <a name="-pcp--pmda--args"></a>`args`

Data type: `Optional[String]`

Arguments that will be added to pmcd.conf for this PMDA

Default value: `undef`

### <a name="pcp--pmie"></a>`pcp::pmie`

Configure a pmie

#### Parameters

The following parameters are available in the `pcp::pmie` defined type:

* [`ensure`](#-pcp--pmie--ensure)
* [`hostname`](#-pcp--pmie--hostname)
* [`primary`](#-pcp--pmie--primary)
* [`socks`](#-pcp--pmie--socks)
* [`log_file`](#-pcp--pmie--log_file)
* [`args`](#-pcp--pmie--args)
* [`config_path`](#-pcp--pmie--config_path)
* [`config_content`](#-pcp--pmie--config_content)
* [`config_source`](#-pcp--pmie--config_source)

##### <a name="-pcp--pmie--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

The pmie ensure property.
Valid values are `present` and `absent`.
Default is `present`.

Default value: `'present'`

##### <a name="-pcp--pmie--hostname"></a>`hostname`

Data type: `String`

Hostname associated with the pmie.
Default is `'LOCALHOSTNAME'`.

Default value: `'LOCALHOSTNAME'`

##### <a name="-pcp--pmie--primary"></a>`primary`

Data type: `Boolean`

Boolean that sets if this pmie is primary.
Default is `false`.

Default value: `false`

##### <a name="-pcp--pmie--socks"></a>`socks`

Data type: `Boolean`

Boolean that sets if this pmie uses pmsocks.
Default is `false`.

Default value: `false`

##### <a name="-pcp--pmie--log_file"></a>`log_file`

Data type: `String`

The pmie control log file.  Default is `PCP_LOG_DIR/pmie/LOCALHOSTNAME/pmie.log`

Default value: `'PCP_LOG_DIR/pmie/LOCALHOSTNAME/pmie.log'`

##### <a name="-pcp--pmie--args"></a>`args`

Data type: `String`

Args passed to pmie.  Default is an empty string.

Default value: `''`

##### <a name="-pcp--pmie--config_path"></a>`config_path`

Data type: `Optional[Stdlib::Absolutepath]`

Config path for the pmie.  If defined the value is passed as `-c value` to the pmie arguments.  Default is `undef`.

Default value: `undef`

##### <a name="-pcp--pmie--config_content"></a>`config_content`

Data type: `Optional[String]`

The pmie config contents.  Default is `undef`.

Default value: `undef`

##### <a name="-pcp--pmie--config_source"></a>`config_source`

Data type: `Optional[String]`

The pmie config source.  Default is `undef`.

Default value: `undef`

### <a name="pcp--pmlogger"></a>`pcp::pmlogger`

Configure a pmlogger

#### Parameters

The following parameters are available in the `pcp::pmlogger` defined type:

* [`ensure`](#-pcp--pmlogger--ensure)
* [`hostname`](#-pcp--pmlogger--hostname)
* [`primary`](#-pcp--pmlogger--primary)
* [`socks`](#-pcp--pmlogger--socks)
* [`log_dir`](#-pcp--pmlogger--log_dir)
* [`args`](#-pcp--pmlogger--args)
* [`config_path`](#-pcp--pmlogger--config_path)
* [`config_content`](#-pcp--pmlogger--config_content)
* [`config_source`](#-pcp--pmlogger--config_source)

##### <a name="-pcp--pmlogger--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

The pmlogger ensure property.
Valid values are `present` and `absent`.
Default is `present`.

Default value: `'present'`

##### <a name="-pcp--pmlogger--hostname"></a>`hostname`

Data type: `String`

Hostname associated with the pmlogger.
Default is `'LOCALHOSTNAME'`.

Default value: `'LOCALHOSTNAME'`

##### <a name="-pcp--pmlogger--primary"></a>`primary`

Data type: `Boolean`

Boolean that sets if this pmlogger is primary.
Default is `false`.

Default value: `false`

##### <a name="-pcp--pmlogger--socks"></a>`socks`

Data type: `Boolean`

Boolean that sets if this pmlogger uses pmsocks.
Default is `false`.

Default value: `false`

##### <a name="-pcp--pmlogger--log_dir"></a>`log_dir`

Data type: `String`

Log directory for this pmlogger.
Default is `PCP_LOG_DIR/pmlogger/LOCALHOSTNAME`.

Default value: `'PCP_LOG_DIR/pmlogger/LOCALHOSTNAME'`

##### <a name="-pcp--pmlogger--args"></a>`args`

Data type: `String`

Arguments passed to pmlogger.
Default is an empty string.

Default value: `''`

##### <a name="-pcp--pmlogger--config_path"></a>`config_path`

Data type: `Optional[Stdlib::Absolutepath]`

Config path for the pmlogger.
If defined the value is passed as `-c value` to the pmlogger arguments.
Default is `undef`.

Default value: `undef`

##### <a name="-pcp--pmlogger--config_content"></a>`config_content`

Data type: `Optional[String]`

The pmlogger config contents.
Default is `undef`.

Default value: `undef`

##### <a name="-pcp--pmlogger--config_source"></a>`config_source`

Data type: `Optional[String]`

The pmlogger config source.
Default is `undef`.

Default value: `undef`

